'use strict';

var moment = require('moment');
var generate = require('./generate');

describe('Generate', function () {
  it('generates dummy xml', function () {
    var baseUrl = 'http://demo.com/';
    var sections = ['demoSection'];
    var title = 'demo title';
    var date = moment('2016-02-21', 'YYYY-MM-DD').utcOffset(0).format();
    var body = 'demo';
    var pages = {
      demo: {
        type: 'page',
        sectionName: 'demoSection',
        file: {
          attributes: {
            date: date,
            title: title
          },
          body: body
        }
      }
    };
    var config = {
      title: 'Demo RSS',
      author: 'Demo Author'
    };
    var updated = moment().format();

    var result = generate({
      baseUrl: baseUrl,
      sections: sections,
      updated: updated,
      pages: pages,
      config: config,
      get: {
        content: function content(page) {
          return page.file.body;
        },
        date: function date(page) {
          return page.file.attributes.date;
        },
        title: function title(page) {
          return page.file.attributes.title;
        }
      }
    });
    var expected = '<feed xmlns="http://www.w3.org/2005/Atom">' + '<title>' + config.title + '</title>' + '<link href="' + baseUrl + 'atom.xml" rel="self"></link>' + '<link href="' + baseUrl + '" rel=""></link>' + '<updated>' + updated + '</updated>' + '<id>' + baseUrl + '</id>' + '<author><name>' + config.author + '</name><email></email></author>' + '<entry>' + '<title>' + title + '</title>' + '<id>ademotitle' + date.toLowerCase() + '</id>' + '<link href="' + baseUrl + 'demo"></link>' + '<updated>' + date + '</updated>' + '<content type="html">' + body + '</content>' + '</entry>' + '</feed>';

    expect(result).toEqual(expected);
  });
});